@@ -18,9 +18,6 @@ import dm.environment
 import kforge.url
 import commands
 
-# Todo: Bug, when PYTHONPATH is set in environment, Python paths are blank
-#       in Apache config, and code doesn't load (esp. mod_python code).
-
 class ApacheConfigBuilder(ApacheConfigBuilder):
     """
     Builds an Apache configuration needed for KForge.
@@ -58,17 +55,18 @@ class ApacheConfigBuilder(ApacheConfigBuilder):
     # todo: Check whether this stuff is really to do with 'hosts' still...
     
     def getMediaHost(self):
-        url_path = self.url_scheme.media_path()
-        media_path = self.dictionary['www.media_root']
+        urlPath = self.url_scheme.media_path()
+        mediaPath = self.dictionary[self.dictionary.words.MEDIA_PATH]
         frag = '''
         Alias %s %s
-        ''' % (url_path, media_path)
+        ''' % (urlPath, mediaPath)
         return frag
     
     def getDjangoHandledPaths(self):
-        admin_paths = ''
-        admin_paths += '^%s$' % self.url_scheme.url_for('home')
-        extra_paths = [
+        adminPaths = ''
+        adminPaths += '^%s$' % self.url_scheme.url_for('home')
+        extraPaths = [
+                self.url_scheme.url_for('feed'),
                 self.url_scheme.url_for('access_denied'),
                 self.url_scheme.url_for('login'),
                 self.url_scheme.url_for('logout'),
@@ -76,12 +74,16 @@ class ApacheConfigBuilder(ApacheConfigBuilder):
                 self.url_scheme.url_for('person'),
                 self.url_scheme.url_for('project'),
                 ]
-        for path in extra_paths:
-            admin_paths += '|^%s($|/.*)' % path
-        return admin_paths
+        for path in extraPaths:
+            adminPaths += '|^%s($|/.*)' % path
+        return adminPaths
 
     def getAdminHostConfig(self):
-        handled_paths = self.getDjangoHandledPaths()
+        handledPaths = self.getDjangoHandledPaths()
+        if self.dictionary[self.dictionary.words.VIRTUALENVBIN_PATH]:
+            djangoHandlerName = 'kforgevirtualenvhandlers::djangohandler'
+        else:
+            djangoHandlerName = 'django.core.handlers.modpython'
         hostFragment = """
         ## *********************************************************
         ## STARTING Kforge 'Django' section 
@@ -94,16 +96,17 @@ class ApacheConfigBuilder(ApacheConfigBuilder):
             %s
             SetHandler python-program
             PythonPath "'%s'.split(':') + sys.path"
-            PythonHandler django.core.handlers.modpython
+            PythonHandler %s
             PythonDebug %s
         </LocationMatch>
 
         ## *********************************************************
         ## ENDING Kforge 'Django' section 
         ## *********************************************************
-        """ % ( handled_paths,
+        """ % ( handledPaths,
                 self.getEnvironmentVariables(),
-                self.dictionary['pythonpath'],
+                self.dictionary[self.dictionary.words.PYTHONPATH],
+                djangoHandlerName,
                 self.pythonDebugMode )
         return hostFragment
     
@@ -149,7 +152,7 @@ class ApacheConfigBuilder(ApacheConfigBuilder):
         """ % (
             systemConfigEnvVarName,
             systemConfigFilePath,
-            self.dictionary['pythonpath']
+            self.dictionary[self.dictionary.words.PYTHONPATH]
         )
     
     def getPluginsCommonConfig(self):
@@ -174,8 +177,12 @@ class ApacheConfigBuilder(ApacheConfigBuilder):
             return "\n# %s\n" % msg
         pluginSystem = service.plugin.getSystem()
         apacheConfigTemplate = pluginSystem.getApacheConfig(service)
+        uriPrefix = self.dictionary[self.dictionary.words.URI_PREFIX]
+        serviceUrl = urlBuilder.getServicePath(service)
+        serviceUrlNoPrefix = serviceUrl.replace(uriPrefix, '', 1)
         varDict = {}
-        varDict['urlPath'] = urlBuilder.getServicePath(service)
+        varDict['urlPath'] = serviceUrl
+        varDict['urlPathNoPrefix'] = serviceUrlNoPrefix
         varDict['fileSystemPath'] = self.fsPathBuilder.getServicePath(service)
         varDict['accessControl'] = self.getAccessControl(service)
         return '\n' + apacheConfigTemplate % varDict
@@ -187,6 +194,12 @@ class ApacheConfigBuilder(ApacheConfigBuilder):
         return self.getModPythonAccessControl()
 
     def getModPythonAccessControl(self):
+        if self.dictionary[self.dictionary.words.VIRTUALENVBIN_PATH]:
+            accessHandlerName = 'kforgevirtualenvhandlers::accesshandler'
+            authenHandlerName = 'kforgevirtualenvhandlers::authenhandler'
+        else:
+            accessHandlerName = 'kforge.handlers.projecthost::accesshandler'
+            authenHandlerName = 'kforge.handlers.projecthost::authenhandler'
         modPythonAccessControl = """
             # Need to set DJANGO as used in both project (auth) and admin
             # Set as PYTHONOPTION as SetEnv does not seem to work in here
@@ -197,8 +210,8 @@ class ApacheConfigBuilder(ApacheConfigBuilder):
 
             # For details see comments in kforge.handlers.projecthost.py
             Satisfy any
-            PythonAccessHandler kforge.handlers.projecthost::accesshandler
-            PythonAuthenHandler kforge.handlers.projecthost::authenhandler
+            PythonAccessHandler %s
+            PythonAuthenHandler %s
             AuthType basic
             AuthName "%s Restricted Area"
             Require valid-user
@@ -210,10 +223,11 @@ class ApacheConfigBuilder(ApacheConfigBuilder):
             """ % (
                 self.systemConfigEnvVarName,
                 self.systemConfigFilePath,
-                self.dictionary['pythonpath'],
+                self.dictionary[self.dictionary.words.PYTHONPATH],
                 self.pythonDebugMode,
-                self.dictionary['service_name'],
+                accessHandlerName,
+                authenHandlerName,
+                self.dictionary[self.dictionary.words.SYSTEM_SERVICE_NAME].decode('utf-8'),
             )
             
         return modPythonAccessControl
-
