@@ -6,17 +6,25 @@ import kforge.accesscontrol
 logger     = RequiredFeature('Logger')
 dictionary = RequiredFeature('SystemDictionary')
 
-def normalizeUrlPath(reqUri):
-    if reqUri[-1] == '/':
-        reqUri = reqUri[:-1]
-    return reqUri
+def isAuthenticated(personName, password):
+    """
+    Authenticate a person with given name and password.
+    """
+    cmd = kforge.command.PersonAuthenticate(personName, password)
+    try:
+        cmd.execute()
+        return cmd.person
+    except kforge.exceptions.KforgeCommandError:
+        pass
+    return None
 
-def isAllowedAccess(personName, reqUri, httpMethod):
+def isAccessAuthorised(person, reqUri, httpMethod):
     urlPath = normalizeUrlPath(reqUri)
-    if len(urlPath.split('/')) > 2:
-        read = kforge.command.PersonRead(personName)
-        read.execute()
-        person = read.person
+    if len(urlPath.split( '/' )) <= 2:
+        # Everything with fewer than two segments is ok (e.g. /project).
+        return True
+    else:
+        # Otherwise control access to a service.
         service = getService(urlPath)
         if not service:
             return False
@@ -30,21 +38,11 @@ def isAllowedAccess(personName, reqUri, httpMethod):
             protectedObject=plugin,
             project=project,
         )
-    # everything with fewer than two segments is ok (e.g. /project)
-    return True
 
-def getVisitorName(personName, password):
-    """
-    Get name to use for authentication given a personName and password.
-    
-    @return: personName if we can authenticate, visitor name otherwise
-    """
-    cmd = kforge.command.PersonAuthenticate(personName, password)
-    try:
-        cmd.execute()
-    except kforge.exceptions.KforgeCommandError:
-        personName = dictionary['visitor']
-    return personName
+def normalizeUrlPath(reqUri):
+    if reqUri[-1] == '/':
+        reqUri = reqUri[:-1]
+    return reqUri
 
 def getService(urlPath):
     """
@@ -56,13 +54,13 @@ def getService(urlPath):
     read = kforge.command.ProjectRead(projectName)
     read.execute()
     project = read.project
-    if serviceName in project.services:
+    try:
         return project.services[serviceName]
-    else:
+    except kforge.exceptions.KforgeRegistryKeyError:
         return None
 
 def getActionName(httpMethod):
-    registry = RequiredFeature('DomainRegistry')
+    #registry = RequiredFeature('DomainRegistry')
     readList = ['GET', 'PROPFIND', 'OPTIONS', 'REPORT']
     if httpMethod in readList:
         return 'Read'
