@@ -41,3 +41,7 @@ class ApplicationBuilder(dm.builder.ApplicationBuilder):
         import kforge.accesscontrol
         return kforge.accesscontrol.ProjectAccessController()
 
+    def findPluginFactory(self):
+        import kforge.plugin.factory
+        return kforge.plugin.factory.PluginFactory()
+
