@@ -20,6 +20,7 @@ class MockEmailNewPassword(EmailNewPassword):
         self.dispatchedMessage['to'] = msgTo
         self.dispatchedMessage['subject'] = msgSubject
         self.dispatchedMessage['body'] = msgBody
+        self.isDispatchedOK = True
 
 
 class TestEmailNewPassword(kforge.testunit.TestCase):
@@ -36,8 +37,8 @@ class TestEmailNewPassword(kforge.testunit.TestCase):
     def testExecute(self):
         self.cmd.execute()
         self.failIf(self.person.isPassword(self.oldPassword))
-        self.failUnless(self.cmd.dispatchedMessage['from'])
-        self.failUnless(self.cmd.dispatchedMessage['to'])
-        self.failUnless(self.cmd.dispatchedMessage['subject'])
-        self.failUnless(self.cmd.dispatchedMessage['body'])
+        self.failUnless(self.cmd.dispatchedMessage['from'], self.cmd.dispatchedMessage)
+        self.failUnless(self.cmd.dispatchedMessage['to'], self.cmd.dispatchedMessage)
+        self.failUnless(self.cmd.dispatchedMessage['subject'], self.cmd.dispatchedMessage)
+        self.failUnless(self.cmd.dispatchedMessage['body'], self.cmd.dispatchedMessage)
 
