@@ -18,6 +18,7 @@ import random
 class KuiTestCase(webunittest.WebTestCase):
 
     system = kforge.soleInstance.application
+    registry = kforge.soleInstance.application.registry
     kuiServer = kforge.url.UrlScheme().getFqdn()
     # use a random port now that we are inserting an intercept
     # kuiPort = system.dictionary['www.port_http']
@@ -55,7 +56,17 @@ class KuiTestCase(webunittest.WebTestCase):
         fullurl = self.siteurl + url
         web.go(fullurl)
         web.code(code)
-        web.find(content)
+        self.webFind(content)
+
+    def webFind(self, requirement):
+        if type(requirement) == str:
+            regexp = requirement
+            web.find(regexp)
+        elif type(requirement) == list:
+            for regexp in requirement:
+                web.find(regexp)
+        else:
+            raise Exception, "Requirement not <type 'str'> or <type 'list'>."
 
     def getAssertNotContent(self, url, content, code=ok_code):
         fullurl = self.siteurl + url
