@@ -5,7 +5,7 @@ import dm.webkit as webkit
 from kforge.ioc import *
 from kforge.exceptions import KforgeCommandError
 import re
-import kforge.re
+import kforge.regexps
 import kforge.command
 
 if webkit.webkitName == 'django' and webkit.webkitVersion == '1.0':
@@ -31,7 +31,7 @@ if webkit.webkitName == 'django' and webkit.webkitVersion == '1.0':
     class PersonNameField(webkit.fields.RegexField):
 
         def __init__(self, *args, **kwargs):
-            regex = '^(?!%s)%s$' % (kforge.re.reservedPersonName, kforge.re.personName)
+            regex = '^(?!%s)%s$' % (kforge.regexps.reservedPersonName, kforge.regexps.personName)
             kwargs['required'] = True
             kwargs['regex'] = regex 
             kwargs['min_length'] = 2
@@ -47,14 +47,14 @@ if webkit.webkitName == 'django' and webkit.webkitVersion == '1.0':
             except KforgeCommandError:
                 pass
             else:
-                message = "Person name is already being used by another person."
+                message = "Login name is already being used by another person."
                 raise webkit.ValidationError(message)
             return value
 
     class ProjectNameField(webkit.fields.RegexField):
         
         def __init__(self, *args, **kwargs):
-            regex = '^(?!%s)%s$' % (kforge.re.reservedProjectName, kforge.re.projectName)
+            regex = '^(?!%s)%s$' % (kforge.regexps.reservedProjectName, kforge.regexps.projectName)
             kwargs['required'] = True
             kwargs['regex'] = regex 
             kwargs['min_length'] = 3
@@ -78,7 +78,7 @@ if webkit.webkitName == 'django' and webkit.webkitVersion == '1.0':
     class ServiceNameField(webkit.fields.RegexField):
         
         def __init__(self, *args, **kwargs):
-            regex = '^%s$' % (kforge.re.serviceName)
+            regex = '^%s$' % (kforge.regexps.serviceName)
             kwargs['required'] = True
             kwargs['regex'] = regex 
             kwargs['min_length'] = 1
@@ -89,14 +89,14 @@ if webkit.webkitName == 'django' and webkit.webkitVersion == '1.0':
 class PersonManipulator(DomainObjectManipulator):
 
     def isPersonName(self, field_data, all_data):
-        pattern = re.compile('^%s$' % kforge.re.personName)
+        pattern = re.compile('^%s$' % kforge.regexps.personName)
         if not pattern.match(field_data):
             msg = "This field can only contain alphanumerics, "
             msg += "underscores, hyphens, and dots."
             raise webkit.ValidationError(msg)
 
     def isReservedPersonName(self, field_data, all_data):
-        pattern = re.compile('^%s$' % kforge.re.reservedPersonName)
+        pattern = re.compile('^%s$' % kforge.regexps.reservedPersonName)
         if pattern.match(field_data):
             msg = "This field is reserved and can not be registered."
             raise webkit.ValidationError(msg)
@@ -108,7 +108,7 @@ class PersonManipulator(DomainObjectManipulator):
         except KforgeCommandError:
             pass
         else:
-            message = "Person name is already being used by another person."
+            message = "Login name is already being used by another person."
             raise webkit.ValidationError(message)
 
     def isMatchingPassword(self, field_data, all_data):
@@ -286,13 +286,13 @@ class PersonUpdateManipulator(PersonManipulator):
 class ProjectManipulator(DomainObjectManipulator):
 
     def isProjectName(self, field_data, all_data):
-        pattern = re.compile('^%s$' % kforge.re.projectName)
+        pattern = re.compile('^%s$' % kforge.regexps.projectName)
         if not pattern.match(field_data):
             msg = "This field can only contain lowercase letters or numbers."
             raise webkit.ValidationError(msg)
 
     def isReservedProjectName(self, field_data, all_data):
-        pattern = re.compile('^%s$' % kforge.re.reservedProjectName)
+        pattern = re.compile('^%s$' % kforge.regexps.reservedProjectName)
         if pattern.match(field_data):
             msg = "This field is reserved and can not be registered."
             raise webkit.ValidationError(msg)
@@ -438,6 +438,9 @@ class MemberCreateManipulator(MemberManipulator):
                     field_name="person", 
                     is_required=True,
                     choices=self.listRegisteredPersons(),
+                    validator_list=[
+                        self.isAvailableMember, 
+                    ]
                 ),
                 webkit.SelectField(
                     field_name="role", 
@@ -446,6 +449,17 @@ class MemberCreateManipulator(MemberManipulator):
                 ),
             )
     
+    def isAvailableMember(self, field_data, all_data):
+        personName = all_data['person']
+        person = self.registry.persons[personName]
+        project = self.objectRegister.owner
+        if not person in project.members:
+            return True
+        else:
+            message = "%s is already a member of this project." % (person.getLabelValue())
+            message += " Please choose another person."
+            raise webkit.ValidationError(message)
+
     def clean(self):
         if 'person' in self.cleaned_data:
             personName = self.cleaned_data['person']
@@ -484,10 +498,9 @@ class MemberUpdateManipulator(MemberManipulator):
 class ServiceManipulator(HasManyManipulator):
 
     def isServiceName(self, field_data, all_data):
-        pattern = re.compile('^%s$' % kforge.re.serviceName)
+        pattern = re.compile('^%s$' % kforge.regexps.serviceName)
         if not pattern.match(field_data):
-            msg = "This field can only contain alphanumerics, "
-            msg += "underscores, and hyphens."
+            msg = "Enter a valid value. "
             raise webkit.ValidationError(msg)
 
     def isAvailableServiceName(self, field_data, all_data):
@@ -510,8 +523,8 @@ class ServiceManipulator(HasManyManipulator):
             project = self.objectRegister.owner
             if serviceName in project.services and \
             not (service and (service.name == serviceName)):
-                msg = u"A service called %s already exists." % (serviceName)
-                #msg += u" Please choose another service name."
+                msg = u"A service called '%s' already exists." % (serviceName)
+                msg += u" Please choose another service name."
                 if 'name' in self._errors:
                     self._errors['name'].append(msg)
                 else:
@@ -540,7 +553,7 @@ class ServiceCreateManipulator(ServiceManipulator):
                 ),
                 webkit.TextField(
                     field_name="name", 
-                    is_required=False,
+                    is_required=True,
                     validator_list=[
                         self.isServiceName,
                         self.isAvailableServiceName,
@@ -569,7 +582,7 @@ class ServiceUpdateManipulator(ServiceManipulator):
             self.fields = (
                 webkit.TextField(
                     field_name="name", 
-                    is_required=False,
+                    is_required=True,
                     validator_list=[
                         self.isServiceName,
                         self.isAvailableServiceName,
