@@ -18,20 +18,12 @@ class ServiceView(ProjectHasManyView):
         super(ServiceView, self).setContext()
         self.context.update({
             'service' : self.getAssociationObject(),
-            'canCreateService': self.canCreateService(),
-            'canUpdateService': self.canUpdateService(),
-            'canDeleteService': self.canDeleteService(),
         })
 
     def setMinorNavigationItem(self):
-        if self.hasManyKey:
-            self.minorNavigationItem = '/project/%s/services/%s/' % (
-                self.domainObjectKey, self.hasManyKey
-            )
-        else:
-            self.minorNavigationItem = '/project/%s/services/' % (
-                self.domainObjectKey
-            )
+        self.minorNavigationItem = '/project/%s/services/' % (
+            self.domainObjectKey
+        )
 
     def makePostManipulateLocation(self):
         return '/project/%s/services/' % (
@@ -39,6 +31,7 @@ class ServiceView(ProjectHasManyView):
         )
 
     def serviceExtendsDomainModel(self):
+        # Todo: Clear up, or explain this method's strange logic. :-)
         service = self.getAssociationObject()
         if not service:
             return False
@@ -64,7 +57,7 @@ class ServiceCreateView(ServiceView, AbstractCreateHasManyView):
         
     def makePostManipulateLocation(self):
         if self.serviceExtendsDomainModel():
-            return '/project/%s/services/%s/extn/create/' % (
+            return '/project/%s/services/%s/edit/' % (
                 self.domainObjectKey,
                 self.getAssociationObject().name
             )
@@ -85,53 +78,103 @@ class ServiceReadView(ServiceView, AbstractReadHasManyView):
     def canAccess(self):
         return self.canReadService()
 
+    def getStatusMessage(self):
+        statusMsg = "No status information"
+        service = self.getAssociationObject()
+        if service:
+            statusMsg = service.getStatusMessage()
+        return statusMsg
+
     def getServiceUserHelp(self):
         service = self.getAssociationObject()
         if service:
             try:
-                userHelp = service.getUserHelp()
+                userHelp = service.getUserHelp(self.getServiceLocation())
             except Exception, inst:
-                userHelp = "Sorry, couldn't retrieve help message. Error message: %s" % str(inst)
+                msg = "Error retrieving user help message: %s" % str(inst)
+                self.logger.error(msg)
+                return ''
             if webkitName == 'django' and webkitVersion == '1.0':
                 from django.utils.safestring import mark_safe
                 return mark_safe(userHelp)
             else:
-                return service.getUserHelp()
+                return userHelp
         return ''
 
+    def setContext(self):
+        super(ServiceReadView, self).setContext()
+        self.context.update({
+            'serviceLocation' : self.getServiceLocation(),
+            'serviceUserHelp': self.getServiceUserHelp(),
+        })
+
+    def getServiceLocation(self):
+        service = self.getAssociationObject()
+        path = service.getUrlPath()
+        socket = self.request.META.get('SERVER_NAME', '')
+        if socket:
+            protocol = 'http'
+            return '%s://%s%s' % (protocol, socket, path)
+        else:
+            return path
+        
 
 class ServiceUpdateView(ServiceView, AbstractUpdateHasManyView):
 
     templatePath = 'service/update'
 
+    def __init__(self, *args, **kwds):
+        super(ServiceUpdateView, self).__init__(*args, **kwds)
+        self.initExtnView()
+
+    def initExtnView(self):
+        if self.serviceExtendsDomainModel():
+            self.extnView = ServiceExtnUpdateView(
+                request=self.request,
+                domainObjectKey=self.domainObjectKey,
+                hasManyKey=self.hasManyKey,
+            )
+        else:
+            self.extnView = None
+
     def canAccess(self):
         return self.canUpdateService()
 
     def makePostManipulateLocation(self):
-        if self.serviceExtendsDomainModel():
-            return '/project/%s/services/%s/extn/update/' % (
-                self.domainObjectKey,
-                self.getAssociationObject().name,
-            )
-        else:
-            return '/project/%s/services/%s/' % (
-                self.domainObjectKey,
-                self.getAssociationObject().name,
-            )
+        return '/project/%s/services/%s/' % (
+            self.domainObjectKey,
+            self.getAssociationObject().name,
+        )
 
     def getManipulatorClass(self):
         return manipulator.ServiceUpdateManipulator
 
+    def getFormErrors(self):
+        formErrors = super(ServiceUpdateView, self).getFormErrors()
+        if self.extnView:
+            extnFormErrors = self.extnView.getFormErrors()
+            if extnFormErrors:
+                formErrors.update(extnFormErrors)
+        return formErrors
 
-class ServiceDeleteView(ServiceView, AbstractDeleteHasManyView):
+    def manipulateDomainObject(self):
+        super(ServiceUpdateView, self).manipulateDomainObject()
+        # Call extention's takeAction() now, so its form errors are involved.
+        if self.extnView:
+            self.extnView.takeAction()
 
-    templatePath = 'service/delete'
-
-    def canAccess(self):
-        return self.canDeleteService()
+    def setContext(self):
+        super(ServiceUpdateView, self).setContext()
+        if self.extnView:
+            form = self.extnView.getForm()
+            self.context.update({
+                'extnForm'       : form,
+            })
 
 
-class ServiceExtnView(ServiceView):
+class ServiceExtnUpdateView(ServiceView, AbstractUpdateHasManyView):
+
+    templatePath = 'serviceExtn/update'
 
     def getManipulatorClass(self):
         return manipulator.ServiceExtnManipulator
@@ -151,14 +194,12 @@ class ServiceExtnView(ServiceView):
         )
 
 
-class ServiceExtnCreateView(ServiceExtnView, ServiceCreateView):
+class ServiceDeleteView(ServiceView, AbstractDeleteHasManyView):
 
-    templatePath = 'serviceExtn/create'
+    templatePath = 'service/delete'
 
-
-class ServiceExtnUpdateView(ServiceExtnView, ServiceUpdateView):
-
-    templatePath = 'serviceExtn/update'
+    def canAccess(self):
+        return self.canDeleteService()
 
 
 def list(request, projectName=''):
@@ -199,19 +240,3 @@ def delete(request, projectName, serviceName):
     )
     return view.getResponse()
 
-def extnCreate(request, projectName, serviceName):
-    view = ServiceExtnCreateView(
-        request=request,
-        domainObjectKey=projectName,
-        hasManyKey=serviceName,
-    )
-    return view.getResponse()
-
-def extnUpdate(request, projectName, serviceName):
-    view = ServiceExtnUpdateView(
-        request=request,
-        domainObjectKey=projectName,
-        hasManyKey=serviceName,
-    )
-    return view.getResponse()
-
