@@ -1,13 +1,12 @@
-# Django settings for KForge project.
-import os
-
+# Django settings for KForge Web interface.
 from django.dispatch import dispatcher
 from django.core import signals
-
 from kforge.soleInstance import application
 from dm.django.settings.main import *
+import os
 
 ROOT_URLCONF = 'kforge.django.settings.urls.main'
+DATABASE_ENGINE = 'postgresql' # Needed to make Django v0.96.3 load 500.html.
 
 # Set the umask for the duration of each request.
 class UmaskSetter(object):
