@@ -1,6 +1,6 @@
 from django.conf.urls.defaults import *
 import re
-import kforge.re
+import kforge.regexps
 # import kforge.url
 # url_scheme = kforge.url.UrlScheme()
 
@@ -12,6 +12,12 @@ urlpatterns = patterns('kforge.django.apps.kui.views',
     (r'^$',
         'kui.welcome'),
 
+    #
+    ##  Feed 
+
+    (r'^feed/$',
+        'kui.feed'),
+
     #
     ##  User Authentication
 
@@ -93,16 +99,16 @@ urlpatterns = patterns('kforge.django.apps.kui.views',
     (r'^person/home/$',
         'person.read'),
         
-    (r'^person/(?P<personName>%s)/$' % kforge.re.personName,
+    (r'^person/(?P<personName>%s)/$' % kforge.regexps.personName,
         'person.read'),
         
-    (r'^person/(?P<personName>%s)/home/$' % kforge.re.personName,
+    (r'^person/(?P<personName>%s)/home/$' % kforge.regexps.personName,
         'person.read'),
         
-    (r'^person/(?P<personName>%s)/edit/$' % kforge.re.personName,
+    (r'^person/(?P<personName>%s)/edit/$' % kforge.regexps.personName,
         'person.update'),
         
-    (r'^person/(?P<personName>%s)/delete/$' % kforge.re.personName,
+    (r'^person/(?P<personName>%s)/delete/$' % kforge.regexps.personName,
         'person.delete'),
 
     #
@@ -126,65 +132,57 @@ urlpatterns = patterns('kforge.django.apps.kui.views',
     (r'^project/home/$',
         'project.read'),
         
-    (r'^project/(?P<projectName>%s)/$' % kforge.re.projectName,
+    (r'^project/(?P<projectName>%s)/$' % kforge.regexps.projectName,
         'project.read'),
         
-    (r'^project/(?P<projectName>%s)/home/$' % kforge.re.projectName,
+    (r'^project/(?P<projectName>%s)/home/$' % kforge.regexps.projectName,
         'project.read'),
         
-    (r'^project/(?P<projectName>%s)/edit/$' % kforge.re.projectName,
+    (r'^project/(?P<projectName>%s)/edit/$' % kforge.regexps.projectName,
         'project.update'),
         
-    (r'^project/(?P<projectName>%s)/delete/$' % kforge.re.projectName,
+    (r'^project/(?P<projectName>%s)/delete/$' % kforge.regexps.projectName,
         'project.delete'),
         
 
     #
     ##  Member
 
-    (r'^project/(?P<projectName>%s)/members/$' % kforge.re.projectName,
+    (r'^project/(?P<projectName>%s)/members/$' % kforge.regexps.projectName,
         'member.list'),
         
-    (r'^project/(?P<projectName>%s)/members/create/$' % kforge.re.projectName,
+    (r'^project/(?P<projectName>%s)/members/create/$' % kforge.regexps.projectName,
         'member.create'),
         
     (r'^project/(?P<projectName>%s)/members/(?P<personName>%s)/edit/$' % (
-        kforge.re.projectName, kforge.re.personName),  
+        kforge.regexps.projectName, kforge.regexps.personName),  
         'member.update'),
         
     (r'^project/(?P<projectName>%s)/members/(?P<personName>%s)/delete/$' % (
-        kforge.re.projectName, kforge.re.personName),  
+        kforge.regexps.projectName, kforge.regexps.personName),  
         'member.delete'),
 
     #
     ##  Service
     
-    (r'^project/(?P<projectName>%s)/services/$' % kforge.re.projectName,
+    (r'^project/(?P<projectName>%s)/services/$' % kforge.regexps.projectName,
         'service.list'),
 
-    (r'^project/(?P<projectName>%s)/services/create/$' % kforge.re.projectName,
+    (r'^project/(?P<projectName>%s)/services/create/$' % kforge.regexps.projectName,
         'service.create'),
 
     (r'^project/(?P<projectName>%s)/services/(?P<serviceName>%s)/edit/$' % (
-        kforge.re.projectName, kforge.re.serviceName),  
+        kforge.regexps.projectName, kforge.regexps.serviceName),  
         'service.update'),
 
     (r'^project/(?P<projectName>%s)/services/(?P<serviceName>%s)/delete/$' % (
-        kforge.re.projectName, kforge.re.serviceName),  
+        kforge.regexps.projectName, kforge.regexps.serviceName),  
         'service.delete'),
 
     (r'^project/(?P<projectName>%s)/services/(?P<serviceName>%s)/$' % (
-        kforge.re.projectName, kforge.re.serviceName),  
+        kforge.regexps.projectName, kforge.regexps.serviceName),  
         'service.read'),
 
-    (r'^project/(?P<projectName>%s)/services/(?P<serviceName>%s)/extn/create/$' % (
-        kforge.re.projectName, kforge.re.serviceName),
-        'service.extnCreate'),
-
-    (r'^project/(?P<projectName>%s)/services/(?P<serviceName>%s)/extn/update/$' % (
-        kforge.re.projectName, kforge.re.serviceName),
-        'service.extnUpdate'),
-
     #
     ##  Not Found
 
