@@ -29,13 +29,16 @@ class TestService(TestCase):
         )
 
     def tearDown(self):
-        super(TestService, self).tearDown()
-        try:
-            self.service.delete()
-        finally:
-            project = self.projects.getAll()['TestService']
-            project.delete()
-            project.purge()
+        project = self.projects.getAll()['TestService']
+        project.delete()
+        project.purge()
+        #super(TestService, self).tearDown()
+        #try:
+        #    self.service.delete()
+        #finally:
+        #    project = self.projects.getAll()['TestService']
+        #    project.delete()
+        #    project.purge()
 
     def test_delete(self):
         self.service.delete()
@@ -52,4 +55,7 @@ class TestService(TestCase):
         self.failUnless(self.service)
         self.failUnless(self.service.project)
         self.assertEquals(self.service.project, self.project)
+        self.failIf(self.service.isSystemUpSinceCreated())
+        self.dictionary.setSystemUpSince()
+        self.failUnless(self.service.isSystemUpSinceCreated())
 
