@@ -49,8 +49,8 @@ class Plugin(kforge.plugin.base.ServicePlugin):
         super(Plugin, self).__init__(domainObject)
     
     def onServiceCreate(self, service):
-        if service and service.plugin and service.plugin.name == 'mailman':
-            self.ensureProjectPluginDirectoryExists(service)
+        if self.isOurs(service):
+            self.assertServicesFolder(service)
             listName = self._getFullListName(service)
             adminEmail = self._getAdminEmail(service)
             adminPass = self.dictionary['mailman.list_admin_password']
@@ -63,7 +63,7 @@ class Plugin(kforge.plugin.base.ServicePlugin):
             self.log(msg)
     
     def onServicePurge(self, service):
-        if service and service.plugin and service.plugin.name == 'mailman':
+        if self.isOurs(service):
             listName = self._getListName(service)
             adminEmail = self._getAdminEmail(service)
             self.deleteMailingList(
