@@ -16,6 +16,8 @@ class PluginTest(TestCase):
     """
     TestCase for the Mailman plugin.
     """
+    tags = [ 'plugin', 'cli' ]
+    disable = True
     
     def setUp(self):
         super(PluginTest, self).setUp()
