@@ -32,16 +32,36 @@ import tarfile
 
 import kforge.plugin.base
 import kforge.utils.backup
+from kforge.dictionarywords import MERCURIAL_ADMIN_SCRIPT
 
 class Plugin(kforge.plugin.base.ServicePlugin):
     
     def __init__(self, domainObject):
         super(Plugin, self).__init__(domainObject)
-        self.utils = MercurialUtils()
+        self.utils = MercurialUtils(self.dictionary[MERCURIAL_ADMIN_SCRIPT])
+
+    def checkDependencies(self):
+        errors = []
+        hgPath = self.dictionary[MERCURIAL_ADMIN_SCRIPT]
+        cmd = 'which %s' % hgPath
+        (status, output) = commands.getstatusoutput(cmd)
+        if status:
+            errors.append("Couldn't find Mercurial admin script '%s' on path." % hgPath)
+        return errors
+
+    def showDepends(self):
+        hgPath = self.dictionary[MERCURIAL_ADMIN_SCRIPT]
+        cmd = 'which %s' % hgPath
+        (status, output) = commands.getstatusoutput(cmd)
+        return [
+            "Mercurial admin: %s" % (status and "Not found!" or ("Found OK. %s" % output)),
+        ]
+
+    showDepends = classmethod(showDepends)
     
     def onServiceCreate(self, service):
-        if service and service.plugin and service.plugin.name == 'mercurial':
-            self.ensureProjectPluginDirectoryExists(service)
+        if self.isOurs(service):
+            self.assertServicesFolder(service)
             path = service.getDirPath()
             self.assertNotFileForPath(path)
             cgi_fo = StringIO(self.hgweb_cgi)
@@ -53,27 +73,17 @@ class Plugin(kforge.plugin.base.ServicePlugin):
             )
             self.log(msg)
     
-    def onServicePurge(self, service):
-        if service and service.plugin and service.plugin.name == 'mercurial':
-            path = service.getDirPath()
-            self.utils.delete(path)
-            self.assertNotFileForPath(path)
-            msg = 'MercurialPlugin: Purged service %s on path: %s' % (
-                service, path
-            )
-            self.log(msg)
-            
     def assertNotFileForPath(self, path):
         if os.path.exists(path):
             message = "Mercurial repository exists on path: %s" % path
             self.logger.error(message)
-            raise message
+            raise Exception(message)
 
     def assertFileForPath(self, path):
         if not os.path.exists(path):
             message = "Mercurial repository doesn't exist on path %s" % path
             self.logger.error(message)
-            raise message
+            raise Exception(message)
     
     def getApacheConfig(self, service):
         config = """
@@ -124,7 +134,10 @@ wsgicgi.launch(wsgiapplication(make_web_app))
 
 
 class MercurialUtils(object):
-    
+   
+    def __init__(self, adminScriptPath='hg'):
+        self.adminScriptPath = adminScriptPath
+ 
     def create_with_web(self, path, cgi_fo, repo_name=''):
         '''Setup mercurial repo with web access.
 
@@ -153,7 +166,7 @@ class MercurialUtils(object):
     def create(self, path):
         if not os.path.exists(path):
             os.makedirs(path)
-        cmd = 'hg init %s' % path
+        cmd = '%s init %s' % (self.adminScriptPath, path)
         status, output = commands.getstatusoutput(cmd)
         if status:
             raise Exception('mercurial create error on %s: %s' % (cmd, output))
