@@ -52,8 +52,8 @@ class Plugin(kforge.plugin.base.ServicePlugin):
         self.utils = kforge.plugin.wordpress.WordpressUtil(master_path)
 
     def onServiceCreate(self, service):
-        if service and service.plugin and service.plugin.name == 'wordpress':
-            self.ensureProjectPluginDirectoryExists(service)
+        if self.isOurs(service):
+            self.assertServicesFolder(service)
             path = service.getDirPath()
             dbTablePrefix = '%s_%s_' % (service.project.name, service.name)
             self.utils.create(path, dbTablePrefix)
@@ -63,15 +63,8 @@ class Plugin(kforge.plugin.base.ServicePlugin):
             self.log(msg)
 
     def onServicePurge(self, service):
-        if service and service.plugin and service.plugin.name == 'wordpress':
-            path = service.getDirPath()
-            if os.path.exists(path):
-                shutil.rmtree(path)
-            # TODO: delete tables from the db
-            msg = 'WordpressPlugin: Deleted service %s on path: %s' % (
-                service, path
-            )
-            self.log(msg)
+        super(Plugin, self).onServicePurge(service)
+        # Todo: Drop Wordpress database instance.
             
     def getApacheConfig(self, service):
         fsPath = self.paths.getProjectPluginPath(service.project, service.plugin)
