@@ -14,6 +14,9 @@ import kforge.plugin.davtest
 import kforge.plugin.svntest
 import kforge.plugin.tractest
 import kforge.plugin.mointest
+import kforge.plugin.wordpresstest
+import kforge.plugin.mailmantest
+import kforge.plugin.notifytest
 
 def suite():
     suites = [
@@ -25,6 +28,9 @@ def suite():
         kforge.plugin.svntest.suite(),
         kforge.plugin.tractest.suite(),
         kforge.plugin.mointest.suite(),
+        kforge.plugin.wordpresstest.suite(),
+        kforge.plugin.mailmantest.suite(),
+        kforge.plugin.notifytest.suite(),
     ]
     return unittest.TestSuite(suites)
 
