@@ -37,8 +37,7 @@ class UrlScheme(object):
         self.host = 'http://' + self.fqdn
         if self.port != '80':
             self.host += ':' + self.port
-        # TODO: support for uri_prefix (from environ or from sysdict)
-        self.uri_prefix = self.dictionary['www.uri_prefix']
+        self.uriPrefix = self.dictionary[self.dictionary.words.URI_PREFIX]
 
         # set up the mapper
         self.mapper = routes.Mapper()
@@ -56,6 +55,7 @@ class UrlScheme(object):
 
     def _configure_mapper(self):
         self.mapper.connect('home', '')
+        self.mapper.connect('feed', 'feed', controller='feed')
         self.mapper.connect('media', 'media*offset', controller='media',
                 offset='')
         self.mapper.connect('logout', 'logout', controller='account',
@@ -111,7 +111,7 @@ class UrlScheme(object):
         config = routes.request_config()
         config.mapper = self.mapper
         url = routes.url_for(*args, **kwargs)
-        url = self.uri_prefix + url
+        url = self.uriPrefix + url
         return url
 
     def url_for_qualified(self, *args, **kwargs):
@@ -153,12 +153,12 @@ class UrlScheme(object):
         #     raise Exception(msg)
         # project = out['project']
         # service = out['service']
-        if self.uri_prefix:
-            if not offset.startswith(self.uri_prefix):
+        if self.uriPrefix:
+            if not offset.startswith(self.uriPrefix):
                 msg = 'No match as %s does not begin with %s' % (offset,
-                        self.uri_prefix)
+                        self.uriPrefix)
                 raise Exception(msg)
-            offset = offset[len(self.uri_prefix):]
+            offset = offset[len(self.uriPrefix):]
         parts = offset.split('/')
         # leading slash will be an item
         if len(parts) < 3:
