@@ -6,8 +6,19 @@ import os
 import kforge.utils.db
 from dm.strategy import FindProtectionObject
 
+class UpgradeDbTo0Point14(kforge.utils.db.Database):
+    """Upgrade system service database from 0.13 to 0.14
+    """
+
+    def execute(self):
+        import kforge
+        app = kforge.getA()
+        sys = app.registry.systems[1]
+        sys.version = '0.14'
+        sys.save()
+
 class UpgradeDbTo0Point13(kforge.utils.db.Database):
-    """Upgrade system service database from 0.10 to 0.11.
+    """Upgrade system service database from 0.13 to 0.14.
     """
 
     sql = '''ALTER TABLE plugin ADD COLUMN last_modified timestamp without time zone;
